@@ -1,5 +1,8 @@
 package App::CreateSelfSignedSSLCert;
 
+our $DATE = '2015-04-02'; # DATE
+our $VERSION = '0.09'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
@@ -14,12 +17,11 @@ use String::ShellQuote;
 
 sub _sq { shell_quote($_[0]) }
 
-our $VERSION = '0.08'; # VERSION
-
 our %SPEC;
 
 $SPEC{create_self_signed_ssl_cert} = {
     v => 1.1,
+    summary => 'Create self-signed SSL certificate',
     args => {
         hostname => {
             schema => ['str*' => match => qr/\A\w+(\.\w+)*\z/],
@@ -29,10 +31,12 @@ $SPEC{create_self_signed_ssl_cert} = {
         ca => {
             summary => 'path to CA cert file',
             schema => ['str*'],
+            'x.completion' => [filename => {file_regex_filter=>qr/\.(crt|pem)$/}],
         },
         ca_key => {
             summary => 'path to CA key file',
             schema => ['str*'],
+            'x.completion' => [filename => {file_regex_filter=>qr/\.(key|pem)$/}],
         },
         interactive => {
             schema => [bool => default => 0],
@@ -166,7 +170,7 @@ App::CreateSelfSignedSSLCert - Create self-signed SSL certificate
 
 =head1 VERSION
 
-This document describes version 0.08 of App::CreateSelfSignedSSLCert (from Perl distribution App-CreateSelfSignedSSLCert), released on 2014-08-16.
+This document describes version 0.09 of App::CreateSelfSignedSSLCert (from Perl distribution App-CreateSelfSignedSSLCert), released on 2015-04-02.
 
 =head1 SYNOPSIS
 
@@ -178,6 +182,8 @@ L<create-self-signed-ssl-cert> and L<create-ssl-csr>.
 
 =head2 create_self_signed_ssl_cert(%args) -> [status, msg, result, meta]
 
+Create self-signed SSL certificate.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -208,8 +214,6 @@ Only when non-interactive
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -219,7 +223,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 create_ssl_csr(%args) -> [status, msg, result, meta]
@@ -240,8 +244,6 @@ Only when non-interactive
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -251,7 +253,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -259,7 +261,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-Create
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-CreateSelfSignedSSL>.
+Source repository is at L<https://github.com/perlancar/perl-App-CreateSelfSignedSSLCert>.
 
 =head1 BUGS
 
@@ -271,11 +273,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
